/* Tabela CODSITUTRIB: SITUACAO TRIBUTARIA */
/* Descrio: A trigger insere registros na tabela LOGOPERA a partir de alteraes na tabela CODSITUTRIB */
/* Objetivo: Gerar um log que vai registrar as alteraes na tabela CODSITUTRIB,
             utilizando a tabela Geral de Logs de Operaes */
CREATE OR REPLACE TRIGGER LOG_FIS_CODSITUTRIB
AFTER DELETE OR INSERT OR UPDATE
ON CODSITUTRIB FOR EACH ROW
DECLARE
  V_DSREMOTEADDR VARCHAR2(15);
  V_DSREMOTEHOST VARCHAR2(15);
  V_DSSERVERRDM  VARCHAR2(20);
  V_DSSERVMETHOD VARCHAR2(30);
  V_DSREMOTEOPER VARCHAR2(12);
  V_USUARIO      VARCHAR2(40);
  V_TIPO         VARCHAR2(1);
  V_ITPESQ       VARCHAR2(40);
  V_DESC         VARCHAR2(300);
  V_DTOPER       DATE;
  V_CDARVPROD    VARCHAR2(20);
  V1_CDARVPROD   VARCHAR2(20);
BEGIN
   V_TIPO := '0';
   V_DESC := '';

   IF DELETING THEN
      IF :OLD.IDENTRSAIDOP IS NOT NULL THEN
         V_DESC := V_DESC || 'EntrSaid=' || :OLD.IDENTRSAIDOP;
      END IF;

      IF :OLD.CDTIPOOPER IS NOT NULL THEN
         V_DESC := V_DESC || ' TipoOper=' || :OLD.CDTIPOOPER;
      END IF;

      IF :OLD.CDEMPRESA IS NOT NULL THEN
         V_DESC := V_DESC || ' Empr=' || :OLD.CDEMPRESA;
      END IF;

      IF :OLD.CDINSCESTA IS NOT NULL THEN
         V_DESC := V_DESC || ' InscEsta=' || :OLD.CDINSCESTA;
      END IF;

      IF :OLD.CDPRODUTO IS NOT NULL THEN
        SELECT MAX(CDARVPROD) INTO V_CDARVPROD
          FROM PRODUTO
         WHERE CDPRODUTO = :OLD.CDPRODUTO;
        IF V_CDARVPROD IS NOT NULL THEN
           V_DESC := V_DESC || ' Prod=' || V_CDARVPROD;
        END IF;
      END IF;

      IF :OLD.CDSITUTRIB IS NOT NULL THEN
         V_DESC := V_DESC || ' CST=' || :OLD.CDSITUTRIB;
      END IF;

      IF :OLD.CDGRUPOFISC IS NOT NULL THEN
         V_DESC := V_DESC || ' GrupFisc=' || :OLD.CDGRUPOFISC;
      END IF;
      
      IF :OLD.IDCSTINTEREST IS NOT NULL THEN
         V_DESC := V_DESC || ' OperIntEst=' || :OLD.IDCSTINTEREST;
      END IF;
      
      IF :OLD.IDCSTINTERNA IS NOT NULL THEN
        V_DESC := V_DESC || ' OperInternacio=' || :OLD.IDCSTINTERNA;
      END IF;

      V_TIPO := '3';
      V_ITPESQ := :OLD.NRINCIDCST;
   
   ELSE       
      IF UPDATING THEN  
         SELECT MAX(CDARVPROD) INTO V1_CDARVPROD
         FROM PRODUTO
         WHERE CDPRODUTO = :NEW.CDPRODUTO;  
         IF (:NEW.IDENTRSAIDOP  <> :OLD.IDENTRSAIDOP) OR
            (:NEW.CDTIPOOPER    <> :OLD.CDTIPOOPER)   OR
            (:NEW.CDEMPRESA     <> :OLD.CDEMPRESA)    OR
            (:NEW.CDINSCESTA    <> :OLD.CDINSCESTA)   OR
            (:NEW.CDPRODUTO     <> :OLD.CDPRODUTO)    OR
            (:NEW.CDSITUTRIB    <> :OLD.CDSITUTRIB)   OR
            (:NEW.CDGRUPOFISC   <> :OLD.CDGRUPOFISC)  OR
            (:NEW.IDCSTINTEREST <> :OLD.IDCSTINTEREST) THEN     

            V_TIPO   := '2';
            V_ITPESQ := :OLD.NRINCIDCST;
         END IF;
      ELSE
         SELECT MAX(CDARVPROD) INTO V1_CDARVPROD
          FROM PRODUTO
         WHERE CDPRODUTO = :NEW.CDPRODUTO;  
         V_TIPO   := '1';
         V_ITPESQ := :NEW.NRINCIDCST;
      END IF;

      IF :NEW.IDENTRSAIDOP IS NOT NULL THEN
         V_DESC := V_DESC || 'EntrSaid=' || :NEW.IDENTRSAIDOP;
      END IF;

      IF :NEW.CDTIPOOPER IS NOT NULL THEN
         V_DESC := V_DESC || ' TipoOper=' || :NEW.CDTIPOOPER;
      END IF;

      IF :NEW.CDEMPRESA IS NOT NULL THEN
         V_DESC := V_DESC || ' Empr=' || :NEW.CDEMPRESA;
      END IF;

      IF :NEW.CDINSCESTA IS NOT NULL THEN
         V_DESC := V_DESC || ' InscEsta=' || :NEW.CDINSCESTA;
      END IF;

      IF V1_CDARVPROD IS NOT NULL THEN
         V_DESC := V_DESC || ' Prod=' || V1_CDARVPROD;
      END IF;

      IF :NEW.CDSITUTRIB IS NOT NULL THEN
         V_DESC := V_DESC || ' CST=' || :NEW.CDSITUTRIB;
      END IF;

      IF :NEW.CDGRUPOFISC IS NOT NULL THEN
         V_DESC := V_DESC || ' GrupFisc=' || :NEW.CDGRUPOFISC;
      END IF;
      
      IF :NEW.IDCSTINTEREST IS NOT NULL THEN
         V_DESC := V_DESC || ' OperIntEst=' || :NEW.IDCSTINTEREST;
      END IF;
      
      IF :NEW.IDCSTINTERNA IS NOT NULL THEN
        V_DESC := V_DESC || ' OperInternacio=' || :NEW.IDCSTINTERNA;
      END IF;
   END IF;

   IF V_TIPO <> '0' THEN
      NMUSUARIO(V_USUARIO);
      WEBTUNNING(V_DSREMOTEADDR,
                 V_DSREMOTEHOST,
                 V_DSSERVERRDM,
                 V_DSSERVMETHOD,
                 V_DSREMOTEOPER);
      IF NOT V_DESC IS NULL THEN
         IF NOT V_USUARIO IS NULL THEN
            V_DTOPER := SYSDATE;

            INSERT INTO LOGOPERA
               (NMTABELA,   DTOPERACAO, NMRESPOPER,
                IDTIPOOPER, CDPESQITEM, DSOPERACAO,
                DSRDMUSUOPER, DSENDUSUOPER, DSNMUSUOPER,
                DSMETUSUOPER, CDORESPOPER)
            VALUES
               ('CODSITUTRIB',  V_DTOPER, V_USUARIO,
                V_TIPO,      V_ITPESQ, V_DESC,
                V_DSSERVERRDM, V_DSREMOTEADDR,
                V_DSREMOTEHOST, V_DSSERVMETHOD,
                V_DSREMOTEOPER);
         END IF;
      END IF;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('LOG_FIS_CODSITUTRIB','5.30.xxx'); END;
/